Memory-efficient identifier representation using Cow
Allows identifiers to be either borrowed from source (&str) or owned (String), reducing allocations when parsing from a string that outlives the AST.
Structs
- CowIdent
- Identifier that can be borrowed or owned (memory-efficient)